SnakeViz
========

About
-----

SnakeViz is a viewer for Python profiling data that runs as a web
application in your browser. It is inspired by the wxPython profile viewer
`RunSnakeRun <http://www.vrplumber.com/programming/runsnakerun/>`_.

Learn more about SnakeViz and submit bug reports at the official page:
http://jiffyclub.github.com/snakeviz/.
